@@ -350,21 +350,21 @@ class VerticaDialect(default.DefaultDialect):
         return table_oid
     
     
-    @reflection.cache
+    
     def get_projection_names(self, connection, schema=None, **kw):
         if schema is not None:
-            schema_condition = "lower(table_schema) = '%(schema)s'" % {'schema': schema.lower()}
+            schema_condition = "lower(projection_schema) = '%(schema)s'" % {'schema': schema.lower()}
         else:
             schema_condition = "1"
-
-        get_tables_sql = sql.text(dedent("""
+            
+        get_projection_sql = sql.text(dedent("""
             SELECT projection_name
-            FROM v_catalog.projections
-            WHERE %(schema_condition)s
-            ORDER BY table_schema, projection_name
-        """ % {'schema_condition': schema_condition}))
-
-        c = connection.execute(get_tables_sql)
+            from v_catalog.projections
+            WHERE lower(projection_schema) =  '%(schema)s'
+            ORDER BY projection_name
+            """  % {'schema': schema}))
+        
+        c = connection.execute(get_projection_sql)   
         return [row[0] for row in c]
 
     @reflection.cache
@@ -644,6 +644,50 @@ class VerticaDialect(default.DefaultDialect):
             autoincrement=autoincrement,
         )
         return column_info
+    
+    def get_models_names(self, connection, schema=None, **kw):
+        
+        if schema is not None:
+            schema_condition = "lower(schema_name) = '%(schema)s'" % {'schema': schema.lower()}
+        else:
+            schema_condition = "1"
+
+        
+        get_models_sql = sql.text(dedent("""
+            SELECT model_name 
+            FROM models
+            WHERE lower(schema_name) =  '%(schema)s'
+            ORDER BY model_name
+        """ % {'schema': schema}))
+
+        c = connection.execute(get_models_sql)
+        
+        return [row[0] for row in c]
+        
+    def get_pk_constraint(self, connection, table_name, schema: None, **kw):
+        if schema is not None:
+            schema_condition = "lower(table_schema) = '%(schema)s'" % {'schema': schema.lower()}
+        else:
+            schema_condition = "1"
+
+        spk = sql.text(dedent("""
+                SELECT column_name
+                FROM v_catalog.primary_keys
+                WHERE lower(table_name) = '%(table)s'
+                AND constraint_type = 'p'
+                AND %(schema_condition)s
+            """ % {'table': table_name.lower(), 'schema_condition': schema_condition}))
+
+        pk_columns = []
+
+        for row in connection.execute(spk):
+            columns = row['column_name']
+            pk_columns.append(columns)
+
+        return {'constrained_columns': pk_columns , 'name': pk_columns}
+        
+        
+      
   
     
 
